[![made at codeastro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/) [![DOI](https://zenodo.org/badge/506017471.svg)](https://zenodo.org/badge/latestdoi/506017471) [![Documentation Status](https://readthedocs.org/projects/datachef/badge/?version=latest)](https://datachef.readthedocs.io/en/latest/?badge=latest)

# DataChef

A lightweight package for creating fake (noisy) data of built-in forms or of a custom, user-provided form.

See DataChef/tutorial.ipynb for a walkthrough of DataChef's features and http://datachef.readthedocs.io/ for the documentation